#include <qfile.h>
#include <qtextstream.h>
#include <qtextview.h>

#include <kdebug.h>

#include <kapp.h>
#include <kcmdlineargs.h>

#include "styleio.h"

int main( int argc, char **argv )
{
  KCmdLineArgs::init( argc, argv, "styleio", "", "" );
  KApplication app;

  StyleIO *win = new StyleIO();
  win->load( "styles.xml" );

  QFile f( "test.rdf" );
  if ( !f.open( IO_ReadOnly ) )
      return false;
  QTextStream ts( &f );
  QString s = ts.read();

  QTextView *view = new QTextView( 0 );
  view->setTextFormat( Qt::RichText );
  view->setStyleSheet( win->stylesheet() );
  view->setText( s );

  view->show();

  app.connect( &app, SIGNAL( lastWindowClosed() ), SLOT( quit() ) );
  app.exec();
}

StyleIO::StyleIO()
{
}

StyleIO::~StyleIO()
{
}

bool StyleIO::load( const QString &filename )
{
    QFile f( filename );

    if ( !f.open( IO_ReadOnly ) )
	return false;

    if ( !doc.setContent( &f ) ) {
      f.close();
      return false;
    }
    f.close();

    walk();
    return true;
}

void StyleIO::walk()
{
    sheet = new QStyleSheet();

    QDomNodeList dnl;
    dnl = doc.elementsByTagName( "style" );
    for ( uint i = 0 ; i < dnl.count() ; i++ ) {
	sheet->insert( processStyle( dnl.item(i).toElement() ) );
    }
}

QStyleSheetItem *StyleIO::processStyle( const QDomElement &elem )
{
    QString name = elem.attribute( "name" );
    kdDebug() << "processStyle, " << name << endl;

    QStyleSheetItem *style = new QStyleSheetItem( sheet, name );
    style->setDisplayMode( QStyleSheetItem::DisplayBlock );

    QDomNode n = elem.firstChild();
    while( !n.isNull() ) {
	QDomElement e = n.toElement();
	if( !e.isNull() ) {
	    if ( e.tagName() == "prop" ) {
		processStyleItem( style, e );
	    }
	}
	n = n.nextSibling();
    }

    return style;
}

void StyleIO::processStyleItem( QStyleSheetItem *item, const QDomElement &e )
{
    QString n = e.attribute( "name" );
    QString v = e.text();
    kdDebug() << "processStyleItem, n = " << n << " v = " << v << endl;

    if ( n == "font-italic" ) {
	item->setFontItalic( true );
    }
    else if ( n == "display" ) {
	if ( v == "block" )
	    item->setDisplayMode( QStyleSheetItem::DisplayBlock );
	else if ( v == "inline" )
	    item->setDisplayMode( QStyleSheetItem::DisplayInline );
	else if ( v == "listitem" ) {
	    item->setDisplayMode( QStyleSheetItem::DisplayListItem );
	    item->setMargin( QStyleSheetItem::MarginLeft, 18 );
	}
	else if ( v == "none" )
	    item->setDisplayMode( QStyleSheetItem::DisplayNone );
    }
    else if ( n == "alignment" ) {
	if ( v == "center" )
	    item->setAlignment( Qt::AlignCenter );
	else if ( v == "left" )
	    item->setAlignment( Qt::AlignLeft );
	else if ( v == "right" )
	    item->setAlignment( Qt::AlignRight );
    }
    else if ( n == "liststyle" ) {
	if ( v == "disc" )
	    item->setListStyle( QStyleSheetItem::ListDisc );
	else if ( v == "circle" )
	    item->setListStyle( QStyleSheetItem::ListCircle );
	else if ( v == "square" )
	    item->setListStyle( QStyleSheetItem::ListSquare );
	else if ( v == "decimal" )
	    item->setListStyle( QStyleSheetItem::ListDecimal );
    }
    else if ( n == "anchor" ) {
    }
}






